@@ -51,10 +51,11 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     mUseDefaultPixmap->setObjectName(QStringLiteral("usedefaultimage"));
     topLayout->addWidget(mUseDefaultPixmap);
 
+#if 0
     mUseHttps = new QCheckBox(i18n("Use HTTPS"), this);
     mUseHttps->setObjectName(QStringLiteral("usehttps"));
     topLayout->addWidget(mUseHttps);
-
+#endif
     mUseLibravatar = new QCheckBox(i18n("Use Libravatar"), this);
     mUseLibravatar->setObjectName(QStringLiteral("uselibravatarcheckbox"));
     topLayout->addWidget(mUseLibravatar);
@@ -117,7 +118,7 @@ void GravatarConfigureSettingsDialog::save()
     saveSpinBox(mGravatarCacheSize, Gravatar::GravatarSettings::self()->gravatarCacheSizeItem());
     saveCheckBox(mFallbackGravatar, Gravatar::GravatarSettings::self()->fallbackToGravatarItem());
     saveCheckBox(mUseLibravatar, Gravatar::GravatarSettings::self()->libravatarSupportEnabledItem());
-    saveCheckBox(mUseHttps, Gravatar::GravatarSettings::self()->gravatarHttpsSupportItem());
+    //saveCheckBox(mUseHttps, Gravatar::GravatarSettings::self()->gravatarHttpsSupportItem());
     accept();
 }
 
@@ -127,7 +128,7 @@ void GravatarConfigureSettingsDialog::load()
     loadWidget(mGravatarCacheSize, Gravatar::GravatarSettings::self()->gravatarCacheSizeItem());
     loadWidget(mFallbackGravatar, Gravatar::GravatarSettings::self()->fallbackToGravatarItem());
     loadWidget(mUseLibravatar, Gravatar::GravatarSettings::self()->libravatarSupportEnabledItem());
-    loadWidget(mUseHttps, Gravatar::GravatarSettings::self()->gravatarHttpsSupportItem());
+    //loadWidget(mUseHttps, Gravatar::GravatarSettings::self()->gravatarHttpsSupportItem());
 }
 
 void GravatarConfigureSettingsDialog::slotClearGravatarCache()
